# Haptik Helpers

*Library of Helpers function to be re used in Haptic Code nodes*

### Installation

```
pip install haptik-helpers
```

### Get started
How to multiply one number by another with this lib:

```Python
from haptik_helpers import Multiplication

# Instantiate a Multiplication object
multiplication = Multiplication(2)

# Call the multiply method
result = multiplication.multiply(5)
```